@@ -1,6 +1,6 @@
 /* Lists of symbols for Bison
 
-   Copyright (C) 2002, 2005-2007, 2009-2015, 2018-2019 Free Software
+   Copyright (C) 2002, 2005-2007, 2009-2015, 2018-2020 Free Software
    Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -34,7 +34,7 @@ symbol_list_sym_new (symbol *sym, location loc)
 
   res->content_type = SYMLIST_SYMBOL;
   res->content.sym = sym;
-  res->location = res->sym_loc = loc;
+  res->sym_loc = loc;
   res->named_ref = NULL;
 
   res->midrule = NULL;
@@ -42,13 +42,14 @@ symbol_list_sym_new (symbol *sym, location loc)
   res->midrule_parent_rhs_index = 0;
 
   /* Members used for LHS only.  */
+  res->rhs_loc = empty_loc;
   res->ruleprec = NULL;
-  res->percent_empty_loc = empty_location;
+  res->percent_empty_loc = empty_loc;
   code_props_none_init (&res->action_props);
   res->dprec = 0;
-  res->dprec_location = empty_location;
+  res->dprec_loc = empty_loc;
   res->merger = 0;
-  res->merger_declaration_location = empty_location;
+  res->merger_declaration_loc = empty_loc;
   res->expected_sr_conflicts = -1;
   res->expected_rr_conflicts = -1;
 
@@ -73,7 +74,7 @@ symbol_list_type_new (uniqstr type_name, location loc)
   res->content.sem_type->location = loc;
   res->content.sem_type->status = undeclared;
 
-  res->location = res->sym_loc = loc;
+  res->sym_loc = loc;
   res->named_ref = NULL;
   res->next = NULL;
 
